@@ -7,11 +7,9 @@ COG_DEFAULT_NAMESPACE = "default"
 VIEWS = 'views'
 STORE="-store-"
 INDEX="-index-"
-INDEX_BLOCK_BASE_LEN = 20 #max store address length
-INDEX_BLOCK_KEYBIT_LEN = int(INDEX_BLOCK_BASE_LEN/2)
-INDEX_BLOCK_LEN = INDEX_BLOCK_BASE_LEN + INDEX_BLOCK_KEYBIT_LEN
+INDEX_BLOCK_LEN = 32
 INDEX_CAPACITY = 100003 # must be a prime number
-INDEX_LOAD_FACTOR = 80
+STORE_READ_BUFFER_SIZE = 512
 
 ''' TORQUE '''
 GRAPH_NODE_SET_TABLE_NAME = 'TOR_NODE_SET'
@@ -27,27 +25,35 @@ def cog_db_path():
     else:
         return "/".join([COG_PATH_PREFIX, COG_HOME])
 
+
 def cog_context():
     return [cog_db_path(), COG_SYS_DIR, COG_SYS_FILE]
 
+
 def cog_instance_sys_file():
     return "/".join(cog_context())
 
+
 def cog_instance_sys_dir():
     return "/".join(cog_context()[0:-1])
 
+
 def cog_views_dir():
     return "/".join([cog_db_path(), VIEWS])
 
+
 def cog_data_dir(db_name):
     return "/".join(cog_context()[0:-2]+[db_name])
 
+
 def cog_index(db_name, table_name, instance_id, index_id):
     return "/".join(cog_context()[0:-2]+[db_name,table_name+INDEX+instance_id+"-"+str(index_id)])
 
+
 def get_table_name(index_file_name):
     return index_file_name.split(INDEX)[0]
 
+
 def index_id(index_name):
     return int(index_name.split("-")[-1])
 
