@@ -28,7 +28,7 @@ class TestDB(unittest.TestCase):
     def test_db(self):
         data = Record('user100','{"firstname":"Hari","lastname":"seldon"}')
         cogdb = Cog()
-        cogdb.create_namespace("test")
+        cogdb.create_or_load_namespace("test")
         cogdb.create_table("db_test", "test")
         cogdb.put(data)
         scanner = cogdb.scanner()
@@ -41,7 +41,7 @@ class TestDB(unittest.TestCase):
 
     def test_list_tables(self):
         cogdb = Cog()
-        cogdb.create_namespace("test_ns")
+        cogdb.create_or_load_namespace("test_ns")
         cogdb.create_table("table1", "test_ns")
         cogdb.create_table("table2", "test_ns")
         cogdb.create_table("table3", "test_ns")
