@@ -35,18 +35,13 @@ class TestIndex2(unittest.TestCase):
         index = Index(tablemeta, config, logger, 0)
         test_size = 30
         for i in range(test_size):
-            print("Index load: "+str(index.get_load()))
             key= ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(10))
             value= ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(100))
             expected_data = Record(key, value)
             position=store.save(expected_data)
-            status=index.put(expected_data.key,position,store)
-            if(status is not None):
-                returned_data=index.get(expected_data.key, store)
-                self.assertTrue(expected_data.is_equal_val(returned_data))
-            else:
-                print("Index has reached its capacity.")
-                break
+            index.put(expected_data.key,position,store)
+            returned_data=index.get(expected_data.key, store)
+            self.assertTrue(expected_data.is_equal_val(returned_data))
 
         c = 0
         scanner = index.scanner(store)
