@@ -18,7 +18,7 @@ class TestLib(unittest.TestCase):
     def test_db(self):
         data = Record('testKey','testVal')
         cogdb = Cog()
-        cogdb.create_namespace("test")
+        cogdb.create_or_load_namespace("test")
         cogdb.create_table("db_test", "test")
         cogdb.put(data)
         self.assertTrue(cogdb.get("testKey").is_equal_val(Record('testKey', 'testVal')))
